/**
 * Copyright (c) 2025 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#include "Heavy_WSTD_DLAY.hpp"

#include <new>

#define Context(_c) static_cast<Heavy_WSTD_DLAY *>(_c)


/*
 * C Functions
 */

extern "C" {
  HV_EXPORT HeavyContextInterface *hv_WSTD_DLAY_new(double sampleRate) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_WSTD_DLAY));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_WSTD_DLAY(sampleRate);
    return Context(ptr);
  }

  HV_EXPORT HeavyContextInterface *hv_WSTD_DLAY_new_with_options(double sampleRate,
      int poolKb, int inQueueKb, int outQueueKb) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_WSTD_DLAY));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_WSTD_DLAY(sampleRate, poolKb, inQueueKb, outQueueKb);
    return Context(ptr);
  }

  HV_EXPORT void hv_WSTD_DLAY_free(HeavyContextInterface *instance) {
    // call destructor
    Context(instance)->~Heavy_WSTD_DLAY();
    // free memory
    hv_free(instance);
  }
} // extern "C"







/*
 * Class Functions
 */

Heavy_WSTD_DLAY::Heavy_WSTD_DLAY(double sampleRate, int poolKb, int inQueueKb, int outQueueKb)
    : HeavyContext(sampleRate, poolKb, inQueueKb, outQueueKb) {
  numBytes += sLine_init(&sLine_emf4FDWb);
  numBytes += sLine_init(&sLine_oP4vcVFl);
  numBytes += sTabhead_init(&sTabhead_oMjHonX9, &hTable_N0BaGJii);
  numBytes += sTabread_init(&sTabread_kAxrWucA, &hTable_N0BaGJii, false);
  numBytes += sTabread_init(&sTabread_N5g2ysVF, &hTable_N0BaGJii, false);
  numBytes += sLine_init(&sLine_Lb0Wp4GL);
  numBytes += sLine_init(&sLine_REWeOjqP);
  numBytes += sLine_init(&sLine_nS7XczOb);
  numBytes += sTabhead_init(&sTabhead_b4PaNVby, &hTable_kOwQFr1w);
  numBytes += sTabread_init(&sTabread_m6Q314kp, &hTable_kOwQFr1w, false);
  numBytes += sTabread_init(&sTabread_WHlA7cSZ, &hTable_kOwQFr1w, false);
  numBytes += sLine_init(&sLine_CvraKWUP);
  numBytes += sTabwrite_init(&sTabwrite_BLdRBwpo, &hTable_N0BaGJii);
  numBytes += sTabwrite_init(&sTabwrite_4Uym1PVk, &hTable_kOwQFr1w);
  numBytes += sRPole_init(&sRPole_eFbjgy40);
  numBytes += sRPole_init(&sRPole_e7sE5NnO);
  numBytes += sRPole_init(&sRPole_6IUyYLed);
  numBytes += sDel1_init(&sDel1_DwTmzkuC);
  numBytes += sLine_init(&sLine_jLgUJtNn);
  numBytes += sLine_init(&sLine_IbXBpd4C);
  numBytes += sRPole_init(&sRPole_14g6YBFI);
  numBytes += sRPole_init(&sRPole_zz8pgRKY);
  numBytes += sRPole_init(&sRPole_GbE9MX7F);
  numBytes += sDel1_init(&sDel1_qdjCShOm);
  numBytes += sLine_init(&sLine_CIAsGIV6);
  numBytes += sLine_init(&sLine_yK7YDNCp);
  numBytes += sLine_init(&sLine_UlLkROZF);
  numBytes += sLine_init(&sLine_CgrCZvKp);
  numBytes += cVar_init_f(&cVar_PZbaKyT3, 0.0f);
  numBytes += cVar_init_f(&cVar_77Ap1qz6, 0.0f);
  numBytes += cVar_init_f(&cVar_Tkysogw1, 0.0f);
  numBytes += cVar_init_f(&cVar_o6y1pE10, 0.0f);
  numBytes += cSlice_init(&cSlice_XgGGHenN, 1, -1);
  numBytes += cVar_init_f(&cVar_aTAPRaiQ, 0.5f);
  numBytes += cSlice_init(&cSlice_yLqrvlyG, 1, -1);
  numBytes += cVar_init_f(&cVar_p3YgE2qW, 0.2f);
  numBytes += cSlice_init(&cSlice_8NJZY6x3, 1, -1);
  numBytes += cVar_init_f(&cVar_t2FtbrbM, 500.0f);
  numBytes += cSlice_init(&cSlice_lOYvjmry, 1, -1);
  numBytes += cVar_init_f(&cVar_uXxq0oP9, 0.25f);
  numBytes += cDelay_init(this, &cDelay_KwGxB0CF, 0.0f);
  numBytes += cDelay_init(this, &cDelay_l6WSwE5H, 0.0f);
  numBytes += hTable_init(&hTable_N0BaGJii, 256);
  numBytes += cDelay_init(this, &cDelay_ZrZQiy8U, 0.0f);
  numBytes += cDelay_init(this, &cDelay_oHSyXk8S, 0.0f);
  numBytes += hTable_init(&hTable_kOwQFr1w, 256);
  numBytes += cVar_init_f(&cVar_PmWaAmKH, 8000.0f);
  numBytes += cBinop_init(&cBinop_h0AkUZxY, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_isN3OkZk, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_bhfHpHcJ, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_che1FDdL, 8000.0f);
  numBytes += cBinop_init(&cBinop_xYSDqeKM, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_bwdL9FzE, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_Y0YN5zNO, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_FkQJUbUs, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_V636omAz, 300.0f);
  numBytes += cBinop_init(&cBinop_ltpjs0j2, 0.0f); // __div
  numBytes += sVarf_init(&sVarf_1bDGg8Zm, 0.0f, 0.0f, false);
  numBytes += cVar_init_s(&cVar_JjRR2dRc, "del-1011-delayL");
  numBytes += sVarf_init(&sVarf_k1z0rgMD, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_vFWBgWZ0, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_I3N2Uj0Z, 0.0f, 0.0f, false);
  numBytes += cVar_init_s(&cVar_d3BDfN2g, "del-1011-delayR");
  numBytes += sVarf_init(&sVarf_A3snDwVx, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_cVsodALY, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_HS55iWfQ, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_3CC62zvN, 8000.0f);
  numBytes += cBinop_init(&cBinop_LqVZ77eD, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_x0hlXezc, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_X3vIjACy, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_AUPgHs5B, 8000.0f);
  numBytes += cBinop_init(&cBinop_gCIIVgH9, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_P1DTlET4, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_A8aLz452, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_tEVKc4D4, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_TAv3K7xJ, 300.0f);
  numBytes += cBinop_init(&cBinop_1bkFcSEw, 0.0f); // __div
  numBytes += sVarf_init(&sVarf_4YuK04Zc, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_BSAMimAp, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_v44uGGd9, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_SBW5yega, 1.0f);
  numBytes += cIf_init(&cIf_3YVtq791, false);
  numBytes += cIf_init(&cIf_Rb0MhOSZ, false);
  numBytes += cVar_init_f(&cVar_m7O9Z5RQ, 0.0f);
  numBytes += cVar_init_f(&cVar_Z7a7jXva, 0.0f);
  numBytes += cVar_init_f(&cVar_3BKWgmrH, 60000.0f);
  numBytes += cVar_init_f(&cVar_LBPr5BVp, 500.0f);
  numBytes += cSlice_init(&cSlice_ExvpjG6Y, 1, -1);
  numBytes += cSlice_init(&cSlice_vtFmCa2e, 1, -1);
  numBytes += cVar_init_f(&cVar_pTYm3pBS, 0.0f);
  numBytes += cIf_init(&cIf_y91VAArF, false);
  numBytes += cBinop_init(&cBinop_uwQzxRP4, 0.0f); // __neq
  numBytes += cVar_init_f(&cVar_5WyPR3B8, 120.0f);
  numBytes += cBinop_init(&cBinop_3f6h1dz7, 0.0f); // __div
  numBytes += cBinop_init(&cBinop_SbPYvnba, 0.0f); // __mul
  
  // schedule a message to trigger all loadbangs via the __hv_init receiver
  scheduleMessageForReceiver(0xCE5CC65B, msg_initWithBang(HV_MESSAGE_ON_STACK(1), 0));
}

Heavy_WSTD_DLAY::~Heavy_WSTD_DLAY() {
  hTable_free(&hTable_N0BaGJii);
  hTable_free(&hTable_kOwQFr1w);
}

HvTable *Heavy_WSTD_DLAY::getTableForHash(hv_uint32_t tableHash) {switch (tableHash) {
    case 0x33B09DD4: return &hTable_N0BaGJii; // del-1011-delayL
    case 0xF057CB49: return &hTable_kOwQFr1w; // del-1011-delayR
    default: return nullptr;
  }
}

void Heavy_WSTD_DLAY::scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) {
  switch (receiverHash) {
    case 0xB6A8F09D: { // Cross
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_wNfMQqR3_sendMessage);
      break;
    }
    case 0x57157946: { // Feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_RFLzIGPZ_sendMessage);
      break;
    }
    case 0x97D46AC6: { // Mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_exbuk3Ra_sendMessage);
      break;
    }
    case 0x4A331B66: { // Sync
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_PaNRhVGH_sendMessage);
      break;
    }
    case 0x58E5C2DB: { // Time
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_kPjdphhq_sendMessage);
      break;
    }
    case 0x49107604: { // TimeSync
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_o3K1qW6Q_sendMessage);
      break;
    }
    case 0xD640D30E: { // 1011-cross
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_PrFZm3q9_sendMessage);
      break;
    }
    case 0xC82F3AD1: { // 1011-feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_MPgghF9k_sendMessage);
      break;
    }
    case 0x6E7C47FF: { // 1011-mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_SbNKxQIO_sendMessage);
      break;
    }
    case 0xD896CBA3: { // 1011-time
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_iXW38ewf_sendMessage);
      break;
    }
    case 0xDF8C2721: { // __hv_dpf_bpm
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_NLbNglHM_sendMessage);
      break;
    }
    case 0xCE5CC65B: { // __hv_init
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_eDuAAHql_sendMessage);
      break;
    }
    default: return;
  }
}

int Heavy_WSTD_DLAY::getParameterInfo(int index, HvParameterInfo *info) {
  if (info != nullptr) {
    switch (index) {
      case 0: {
        info->name = "Cross";
        info->hash = 0xB6A8F09D;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 20.0f;
        break;
      }
      case 1: {
        info->name = "Feedback";
        info->hash = 0x57157946;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 25.0f;
        break;
      }
      case 2: {
        info->name = "Mix";
        info->hash = 0x97D46AC6;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 50.0f;
        break;
      }
      case 3: {
        info->name = "Sync";
        info->hash = 0x4A331B66;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 4: {
        info->name = "Time";
        info->hash = 0x58E5C2DB;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 50.0f;
        info->maxVal = 5000.0f;
        info->defaultVal = 500.0f;
        break;
      }
      case 5: {
        info->name = "TimeSync";
        info->hash = 0x49107604;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 12.0f;
        info->defaultVal = 6.0f;
        break;
      }
      default: {
        info->name = "invalid parameter index";
        info->hash = 0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 0.0f;
        info->defaultVal = 0.0f;
        break;
      }
    }
  }
  return 6;
}



/*
 * Send Function Implementations
 */


void Heavy_WSTD_DLAY::cVar_PZbaKyT3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_q2SDC9dR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cVar_77Ap1qz6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_72iZ9rYJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cVar_Tkysogw1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_PbxkHKr8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cVar_o6y1pE10_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_vUZswUXr_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cSwitchcase_knsfy0Yj_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x764F1C36: { // "mix"
      cSlice_onMessage(_c, &Context(_c)->cSlice_XgGGHenN, 0, m, &cSlice_XgGGHenN_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DLAY::cSlice_XgGGHenN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_nmgx4RnX_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_nmgx4RnX_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DLAY::cVar_aTAPRaiQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_nmgx4RnX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cSend_nmgx4RnX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_SbNKxQIO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cSwitchcase_E9Xv6yYY_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xC8CCFEC1: { // "cross"
      cSlice_onMessage(_c, &Context(_c)->cSlice_yLqrvlyG, 0, m, &cSlice_yLqrvlyG_sendMessage);
      break;
    }
    default: {
      cSwitchcase_BKgNX7ik_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DLAY::cSlice_yLqrvlyG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_0KiQRTqh_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_0KiQRTqh_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DLAY::cVar_p3YgE2qW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_0KiQRTqh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cSend_0KiQRTqh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_PrFZm3q9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cSwitchcase_Us54oHmx_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x8E55AA5F: { // "time"
      cSlice_onMessage(_c, &Context(_c)->cSlice_8NJZY6x3, 0, m, &cSlice_8NJZY6x3_sendMessage);
      break;
    }
    default: {
      cSwitchcase_knsfy0Yj_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DLAY::cSlice_8NJZY6x3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_ZUJt0Nqh_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_ZUJt0Nqh_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DLAY::cVar_t2FtbrbM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_ZUJt0Nqh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cSend_ZUJt0Nqh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_iXW38ewf_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cBinop_q8PdgrG1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_EyGAf9ph_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_EyGAf9ph_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_hIbKcKzv_sendMessage);
}

void Heavy_WSTD_DLAY::cUnop_nEhIv7Yq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_z9B3HWHc_sendMessage(_c, 0, m);
  cMsg_msbWbXgN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cUnop_bw7WZ9t0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_HGnDe7D6_sendMessage(_c, 0, m);
  cMsg_DRCbeWQQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cBinop_hIbKcKzv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_B10ywv37_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_B10ywv37_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_xfb0L59T_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_JDtvsf2H_sendMessage);
}

void Heavy_WSTD_DLAY::cCast_JDtvsf2H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_XNPijd3Q_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cCast_xfb0L59T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_vXpprqpB_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_vXpprqpB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_sKmTNGCB_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_XNPijd3Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_qiuQcfcP_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_qiuQcfcP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_3dtAyK0K_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_sKmTNGCB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SQRT, m, &cUnop_nEhIv7Yq_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_3dtAyK0K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SQRT, m, &cUnop_bw7WZ9t0_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_rpEPfjnH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_sYBUimMt_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_sYBUimMt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_k9OX9xgY_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_k9OX9xgY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_9lxQ1G8h_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_9lxQ1G8h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_rBqUe9KB_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_F1cdW4H7_sendMessage);
}

void Heavy_WSTD_DLAY::cCast_rBqUe9KB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_jjqDXsxK_sendMessage);
}

void Heavy_WSTD_DLAY::cCast_F1cdW4H7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_jQdimTgN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cBinop_jjqDXsxK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_LVrFPM68_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_jQdimTgN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_O5YO2XS8_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_O5YO2XS8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_HcLSaWyV_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_HcLSaWyV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_GNc5ZNyv_sendMessage(_c, 0, m);
  cMsg_yhesJSHq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cBinop_LVrFPM68_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_yRHi62tf_sendMessage(_c, 0, m);
  cMsg_sLov1csS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cSwitchcase_BKgNX7ik_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xF1E7CD16: { // "feedback"
      cSlice_onMessage(_c, &Context(_c)->cSlice_lOYvjmry, 0, m, &cSlice_lOYvjmry_sendMessage);
      break;
    }
    default: {
      cSwitchcase_Us54oHmx_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DLAY::cSlice_lOYvjmry_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_D0AG8uiz_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_D0AG8uiz_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DLAY::cVar_uXxq0oP9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_D0AG8uiz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cSend_D0AG8uiz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_MPgghF9k_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cMsg_4NHYinou_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_6WxmILaG_sendMessage);
}

void Heavy_WSTD_DLAY::cSystem_6WxmILaG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_iO0I4ybK_sendMessage);
}

void Heavy_WSTD_DLAY::cDelay_KwGxB0CF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_KwGxB0CF, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_l6WSwE5H, 0, m, &cDelay_l6WSwE5H_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_KwGxB0CF, 0, m, &cDelay_KwGxB0CF_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_BLdRBwpo, 1, m, NULL);
}

void Heavy_WSTD_DLAY::cDelay_l6WSwE5H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_l6WSwE5H, m);
  cMsg_riauiRVY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cSwitchcase_zq9W55QJ_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_rKpaF13w_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DLAY::cBinop_Ii2iJl7N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_XhVxLnEJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::hTable_N0BaGJii_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_hMtYRHOI_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_KwGxB0CF, 2, m, &cDelay_KwGxB0CF_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_k9n2tsct_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_XhVxLnEJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_N0BaGJii, 0, m, &hTable_N0BaGJii_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_iO0I4ybK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 5000.0f, 0, m, &cBinop_Ii2iJl7N_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_riauiRVY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_N0BaGJii, 0, m, &hTable_N0BaGJii_sendMessage);
}

void Heavy_WSTD_DLAY::cCast_k9n2tsct_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_KwGxB0CF, 0, m, &cDelay_KwGxB0CF_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_hMtYRHOI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_l6WSwE5H, 2, m, &cDelay_l6WSwE5H_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_rKpaF13w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_BLdRBwpo, 1, m, NULL);
}

void Heavy_WSTD_DLAY::cMsg_anMmhJ1N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_ZMhZxrE7_sendMessage);
}

void Heavy_WSTD_DLAY::cSystem_ZMhZxrE7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_6QkBu4Lq_sendMessage);
}

void Heavy_WSTD_DLAY::cDelay_ZrZQiy8U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_ZrZQiy8U, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_oHSyXk8S, 0, m, &cDelay_oHSyXk8S_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_ZrZQiy8U, 0, m, &cDelay_ZrZQiy8U_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_4Uym1PVk, 1, m, NULL);
}

void Heavy_WSTD_DLAY::cDelay_oHSyXk8S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_oHSyXk8S, m);
  cMsg_sPjSNYEe_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cSwitchcase_cMwBNChz_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_bmXocgFj_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DLAY::cBinop_XB3Rd6x1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_JeDn2iCK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::hTable_kOwQFr1w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_h8HIXTgk_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_ZrZQiy8U, 2, m, &cDelay_ZrZQiy8U_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_2ZH8Idlr_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_JeDn2iCK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_kOwQFr1w, 0, m, &hTable_kOwQFr1w_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_6QkBu4Lq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 5000.0f, 0, m, &cBinop_XB3Rd6x1_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_sPjSNYEe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_kOwQFr1w, 0, m, &hTable_kOwQFr1w_sendMessage);
}

void Heavy_WSTD_DLAY::cCast_2ZH8Idlr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_ZrZQiy8U, 0, m, &cDelay_ZrZQiy8U_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_h8HIXTgk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_oHSyXk8S, 2, m, &cDelay_oHSyXk8S_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_bmXocgFj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_4Uym1PVk, 1, m, NULL);
}

void Heavy_WSTD_DLAY::cVar_PmWaAmKH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_h0AkUZxY, HV_BINOP_MULTIPLY, 0, m, &cBinop_h0AkUZxY_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_Cr0DdcSR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_JR1Gjv8G_sendMessage);
}

void Heavy_WSTD_DLAY::cSystem_JR1Gjv8G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_TrDmpzHj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cBinop_h0AkUZxY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_ug1hxhuE_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_otQEu6up_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_h0AkUZxY, HV_BINOP_MULTIPLY, 1, m, &cBinop_h0AkUZxY_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_TrDmpzHj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_otQEu6up_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_ug1hxhuE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_oXjfZdRu_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_oXjfZdRu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_InX3GylI_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_bhfHpHcJ, m);
}

void Heavy_WSTD_DLAY::cBinop_InX3GylI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_isN3OkZk, m);
}

void Heavy_WSTD_DLAY::cVar_che1FDdL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_xYSDqeKM, HV_BINOP_MULTIPLY, 0, m, &cBinop_xYSDqeKM_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_mF2PBnMU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_ecMcyAt4_sendMessage);
}

void Heavy_WSTD_DLAY::cSystem_ecMcyAt4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_AGv9WNN3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cBinop_xYSDqeKM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_S7ZfCqVr_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_QDnXAqLv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_xYSDqeKM, HV_BINOP_MULTIPLY, 1, m, &cBinop_xYSDqeKM_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_AGv9WNN3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_QDnXAqLv_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_S7ZfCqVr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_vYEtxZpl_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_vYEtxZpl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_Sk7NIIug_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_Y0YN5zNO, m);
}

void Heavy_WSTD_DLAY::cBinop_Sk7NIIug_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_bwdL9FzE, m);
}

void Heavy_WSTD_DLAY::cBinop_y7kJh4Fn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_SIY38Oux_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_SIY38Oux_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_fNLsFOnD_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_MaffCoxn_sendMessage);
}

void Heavy_WSTD_DLAY::cVar_V636omAz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.0f, 0, m, &cBinop_HYOeIJI9_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_h4x4XJ8n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_8tpvHVNa_sendMessage);
}

void Heavy_WSTD_DLAY::cSystem_8tpvHVNa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ltpjs0j2, HV_BINOP_DIVIDE, 1, m, &cBinop_ltpjs0j2_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_fNLsFOnD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_X3stMeUt_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_X3stMeUt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_1bDGg8Zm, m);
}

void Heavy_WSTD_DLAY::cMsg_tlNzhii3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_dEXfpUCX_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_dEXfpUCX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_y7kJh4Fn_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_MaffCoxn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_FkQJUbUs, m);
}

void Heavy_WSTD_DLAY::cBinop_HYOeIJI9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 6.28319f, 0, m, &cBinop_CetCT8fs_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_CetCT8fs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ltpjs0j2, HV_BINOP_DIVIDE, 0, m, &cBinop_ltpjs0j2_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_ltpjs0j2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_tlNzhii3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cMsg_6mRLnOcD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_X3sq4UqO_sendMessage);
}

void Heavy_WSTD_DLAY::cSystem_X3sq4UqO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_5scJTxJm_sendMessage);
}

void Heavy_WSTD_DLAY::cVar_JjRR2dRc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_1xSBHV9j_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cSystem_iL5vFiOv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_N1o7yguv_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_k1z0rgMD, m);
}

void Heavy_WSTD_DLAY::cBinop_5scJTxJm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_vFWBgWZ0, m);
}

void Heavy_WSTD_DLAY::cMsg_1xSBHV9j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_iL5vFiOv_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_N1o7yguv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_I3N2Uj0Z, m);
}

void Heavy_WSTD_DLAY::cMsg_jxkgFD2X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_hC13uXjZ_sendMessage);
}

void Heavy_WSTD_DLAY::cSystem_hC13uXjZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_XjthfrKP_sendMessage);
}

void Heavy_WSTD_DLAY::cVar_d3BDfN2g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_kjTt398t_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cSystem_LTkeDZZ6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_IQLrfyxn_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_A3snDwVx, m);
}

void Heavy_WSTD_DLAY::cBinop_XjthfrKP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_cVsodALY, m);
}

void Heavy_WSTD_DLAY::cMsg_kjTt398t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_LTkeDZZ6_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_IQLrfyxn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_HS55iWfQ, m);
}

void Heavy_WSTD_DLAY::cVar_3CC62zvN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_LqVZ77eD, HV_BINOP_MULTIPLY, 0, m, &cBinop_LqVZ77eD_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_ZyG7iRV7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_UFJGOZWE_sendMessage);
}

void Heavy_WSTD_DLAY::cSystem_UFJGOZWE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_cn11LCGV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cBinop_LqVZ77eD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_KmlmVmlr_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_wYDVbz13_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_LqVZ77eD, HV_BINOP_MULTIPLY, 1, m, &cBinop_LqVZ77eD_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_cn11LCGV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_wYDVbz13_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_KmlmVmlr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_ickWJYNK_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_ickWJYNK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_D5azkSxi_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_X3vIjACy, m);
}

void Heavy_WSTD_DLAY::cBinop_D5azkSxi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_x0hlXezc, m);
}

void Heavy_WSTD_DLAY::cVar_AUPgHs5B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_gCIIVgH9, HV_BINOP_MULTIPLY, 0, m, &cBinop_gCIIVgH9_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_l8lzn7WC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_PGO5IagE_sendMessage);
}

void Heavy_WSTD_DLAY::cSystem_PGO5IagE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_GCbrokq1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cBinop_gCIIVgH9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_yMuJakTq_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_ofSX4ZnR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_gCIIVgH9, HV_BINOP_MULTIPLY, 1, m, &cBinop_gCIIVgH9_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_GCbrokq1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_ofSX4ZnR_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_yMuJakTq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_8hQmbsKF_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_8hQmbsKF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_i80uts2E_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_A8aLz452, m);
}

void Heavy_WSTD_DLAY::cBinop_i80uts2E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_P1DTlET4, m);
}

void Heavy_WSTD_DLAY::cBinop_b5RSyRue_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_znwrxYen_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_znwrxYen_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_EDpc2UBj_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_JBInPdqY_sendMessage);
}

void Heavy_WSTD_DLAY::cVar_TAv3K7xJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.0f, 0, m, &cBinop_0ejbn1c3_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_RLapHdOD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_qsWSv9aG_sendMessage);
}

void Heavy_WSTD_DLAY::cSystem_qsWSv9aG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_1bkFcSEw, HV_BINOP_DIVIDE, 1, m, &cBinop_1bkFcSEw_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_EDpc2UBj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_HB0jwDjH_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_HB0jwDjH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_4YuK04Zc, m);
}

void Heavy_WSTD_DLAY::cMsg_oxb2KLbX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_TJ3eMJPR_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_TJ3eMJPR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_b5RSyRue_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_JBInPdqY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_tEVKc4D4, m);
}

void Heavy_WSTD_DLAY::cBinop_0ejbn1c3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 6.28319f, 0, m, &cBinop_XAHIfK9u_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_XAHIfK9u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_1bkFcSEw, HV_BINOP_DIVIDE, 0, m, &cBinop_1bkFcSEw_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_1bkFcSEw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_oxb2KLbX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cMsg_z9B3HWHc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Lb0Wp4GL, 0, m, NULL);
}

void Heavy_WSTD_DLAY::cMsg_HGnDe7D6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_emf4FDWb, 0, m, NULL);
}

void Heavy_WSTD_DLAY::cMsg_DRCbeWQQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_REWeOjqP, 0, m, NULL);
}

void Heavy_WSTD_DLAY::cMsg_msbWbXgN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_CvraKWUP, 0, m, NULL);
}

void Heavy_WSTD_DLAY::cMsg_sLov1csS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_yK7YDNCp, 0, m, NULL);
}

void Heavy_WSTD_DLAY::cMsg_GNc5ZNyv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_IbXBpd4C, 0, m, NULL);
}

void Heavy_WSTD_DLAY::cMsg_yRHi62tf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_CgrCZvKp, 0, m, NULL);
}

void Heavy_WSTD_DLAY::cMsg_yhesJSHq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_UlLkROZF, 0, m, NULL);
}

void Heavy_WSTD_DLAY::cMsg_Y18FzWi4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_oP4vcVFl, 0, m, NULL);
}

void Heavy_WSTD_DLAY::cMsg_e3RkmEph_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_nS7XczOb, 0, m, NULL);
}

void Heavy_WSTD_DLAY::cMsg_KJe8qW9r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_jLgUJtNn, 0, m, NULL);
}

void Heavy_WSTD_DLAY::cMsg_mAyZ6iV4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_CIAsGIV6, 0, m, NULL);
}

void Heavy_WSTD_DLAY::cVar_SBW5yega_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_rbRr6Wfn_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_HjyGqrxD_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_8whLb0ZO_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_rbRr6Wfn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_SBW5yega, 1, m, &cVar_SBW5yega_sendMessage);
}

void Heavy_WSTD_DLAY::cIf_3YVtq791_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_77Ap1qz6, 0, m, &cVar_77Ap1qz6_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DLAY::cIf_Rb0MhOSZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_77Ap1qz6, 0, m, &cVar_77Ap1qz6_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DLAY::cVar_m7O9Z5RQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Rb0MhOSZ, 0, m, &cIf_Rb0MhOSZ_sendMessage);
}

void Heavy_WSTD_DLAY::cVar_Z7a7jXva_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_3YVtq791, 0, m, &cIf_3YVtq791_sendMessage);
}

void Heavy_WSTD_DLAY::cVar_3BKWgmrH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_3f6h1dz7, HV_BINOP_DIVIDE, 0, m, &cBinop_3f6h1dz7_sendMessage);
}

void Heavy_WSTD_DLAY::cVar_LBPr5BVp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_SbPYvnba, HV_BINOP_MULTIPLY, 1, m, &cBinop_SbPYvnba_sendMessage);
}

void Heavy_WSTD_DLAY::cSwitchcase_psV60ts8_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xFFFFFFFF: { // "bang"
      cSlice_onMessage(_c, &Context(_c)->cSlice_ExvpjG6Y, 0, m, &cSlice_ExvpjG6Y_sendMessage);
      break;
    }
    case 0x3E004DAB: { // "set"
      cSlice_onMessage(_c, &Context(_c)->cSlice_vtFmCa2e, 0, m, &cSlice_vtFmCa2e_sendMessage);
      break;
    }
    default: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_hTdLFlxa_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_eERrjgFM_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_DLAY::cSlice_ExvpjG6Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cVar_onMessage(_c, &Context(_c)->cVar_pTYm3pBS, 0, m, &cVar_pTYm3pBS_sendMessage);
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_pTYm3pBS, 0, m, &cVar_pTYm3pBS_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DLAY::cSlice_vtFmCa2e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_uwQzxRP4, HV_BINOP_NEQ, 1, m, &cBinop_uwQzxRP4_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_pTYm3pBS, 1, m, &cVar_pTYm3pBS_sendMessage);
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_uwQzxRP4, HV_BINOP_NEQ, 1, m, &cBinop_uwQzxRP4_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_pTYm3pBS, 1, m, &cVar_pTYm3pBS_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DLAY::cVar_pTYm3pBS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 5000.0f, 0, m, &cBinop_RHHi3KiD_sendMessage);
}

void Heavy_WSTD_DLAY::cIf_y91VAArF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_gzwsb9SD_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_9UCNgR4x_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DLAY::cCast_9UCNgR4x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_pTYm3pBS, 0, m, &cVar_pTYm3pBS_sendMessage);
}

void Heavy_WSTD_DLAY::cCast_gzwsb9SD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_uwQzxRP4, HV_BINOP_NEQ, 1, m, &cBinop_uwQzxRP4_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_uwQzxRP4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_y91VAArF, 1, m, &cIf_y91VAArF_sendMessage);
}

void Heavy_WSTD_DLAY::cCast_eERrjgFM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_y91VAArF, 0, m, &cIf_y91VAArF_sendMessage);
}

void Heavy_WSTD_DLAY::cCast_hTdLFlxa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_uwQzxRP4, HV_BINOP_NEQ, 0, m, &cBinop_uwQzxRP4_sendMessage);
}

void Heavy_WSTD_DLAY::cVar_5WyPR3B8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_fmkoVULX_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_WnVEyx24_sendMessage);
}

void Heavy_WSTD_DLAY::cSwitchcase_dCbNRisx_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_CpknqNbu_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_h8x9A1Yr_sendMessage);
      break;
    }
    case 0x40000000: { // "2.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_WPR7XzHu_sendMessage);
      break;
    }
    case 0x40400000: { // "3.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_vU6Yg17T_sendMessage);
      break;
    }
    case 0x40800000: { // "4.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_cPDXiepd_sendMessage);
      break;
    }
    case 0x40A00000: { // "5.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_RKQDuRYi_sendMessage);
      break;
    }
    case 0x40C00000: { // "6.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_acafYlU1_sendMessage);
      break;
    }
    case 0x40E00000: { // "7.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_NqxHmtcr_sendMessage);
      break;
    }
    case 0x41000000: { // "8.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_KUDxWa9a_sendMessage);
      break;
    }
    case 0x41100000: { // "9.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_CDr5324S_sendMessage);
      break;
    }
    case 0x41200000: { // "10.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_qLgcwuqC_sendMessage);
      break;
    }
    case 0x41300000: { // "11.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_564sE2xu_sendMessage);
      break;
    }
    case 0x41400000: { // "12.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_t7rdEsyw_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DLAY::cCast_CpknqNbu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_XZLNAYhA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cCast_h8x9A1Yr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Gatr9wno_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cCast_WPR7XzHu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_JDLiXeoU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cCast_vU6Yg17T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_LiWZrm3z_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cCast_cPDXiepd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_HMe8ASua_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cCast_RKQDuRYi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_fZ8BO2gc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cCast_acafYlU1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_XyVVlXPw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cCast_NqxHmtcr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_p93RNYfy_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cCast_KUDxWa9a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_x434Mj6C_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cCast_CDr5324S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_FmTP4aUT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cCast_qLgcwuqC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_7eyKfRXn_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cCast_564sE2xu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ISFHjhSJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cCast_t7rdEsyw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_iPgIR0ab_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cBinop_3f6h1dz7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_SbPYvnba, HV_BINOP_MULTIPLY, 0, m, &cBinop_SbPYvnba_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_SbPYvnba_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_psV60ts8_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DLAY::cCast_WnVEyx24_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_3BKWgmrH, 0, m, &cVar_3BKWgmrH_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_LBPr5BVp, 0, m, &cVar_LBPr5BVp_sendMessage);
}

void Heavy_WSTD_DLAY::cCast_fmkoVULX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_3f6h1dz7, HV_BINOP_DIVIDE, 1, m, &cBinop_3f6h1dz7_sendMessage);
}

void Heavy_WSTD_DLAY::cCast_ROys5eUj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_3BKWgmrH, 0, m, &cVar_3BKWgmrH_sendMessage);
}

void Heavy_WSTD_DLAY::cCast_OqrGb7tJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_LBPr5BVp, 0, m, &cVar_LBPr5BVp_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_XZLNAYhA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.166667f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_OqrGb7tJ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ROys5eUj_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_Gatr9wno_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.2f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_OqrGb7tJ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ROys5eUj_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_JDLiXeoU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.25f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_OqrGb7tJ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ROys5eUj_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_LiWZrm3z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.333333f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_OqrGb7tJ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ROys5eUj_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_HMe8ASua_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.6f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_OqrGb7tJ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ROys5eUj_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_fZ8BO2gc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.666667f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_OqrGb7tJ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ROys5eUj_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_XyVVlXPw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_OqrGb7tJ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ROys5eUj_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_p93RNYfy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.5f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_OqrGb7tJ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ROys5eUj_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_x434Mj6C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 2.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_OqrGb7tJ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ROys5eUj_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_FmTP4aUT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 3.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_OqrGb7tJ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ROys5eUj_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_7eyKfRXn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 4.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_OqrGb7tJ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ROys5eUj_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_ISFHjhSJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 5.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_OqrGb7tJ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ROys5eUj_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_iPgIR0ab_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_OqrGb7tJ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ROys5eUj_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_vUZswUXr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mix");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_E9Xv6yYY_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DLAY::cMsg_q2SDC9dR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "feedback");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_E9Xv6yYY_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DLAY::cBinop_qJbpXKnI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_o6y1pE10, 0, m, &cVar_o6y1pE10_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_PyrJGVG3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_PZbaKyT3, 0, m, &cVar_PZbaKyT3_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_IEBAU5Pv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Tkysogw1, 0, m, &cVar_Tkysogw1_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_72iZ9rYJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "time");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_E9Xv6yYY_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DLAY::cMsg_PbxkHKr8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "cross");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_E9Xv6yYY_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DLAY::cBinop_RHHi3KiD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Z7a7jXva, 0, m, &cVar_Z7a7jXva_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_8whLb0ZO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_bbQ0nm85_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_FBPUN72b_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_HjyGqrxD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_edHCusAk_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_hwQZnh9z_sendMessage);
}

void Heavy_WSTD_DLAY::cCast_hwQZnh9z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_m7O9Z5RQ, 0, m, &cVar_m7O9Z5RQ_sendMessage);
}

void Heavy_WSTD_DLAY::cCast_edHCusAk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Rb0MhOSZ, 1, m, &cIf_Rb0MhOSZ_sendMessage);
}

void Heavy_WSTD_DLAY::cCast_bbQ0nm85_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_3YVtq791, 1, m, &cIf_3YVtq791_sendMessage);
}

void Heavy_WSTD_DLAY::cCast_FBPUN72b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Z7a7jXva, 0, m, &cVar_Z7a7jXva_sendMessage);
}

void Heavy_WSTD_DLAY::cReceive_exbuk3Ra_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_qJbpXKnI_sendMessage);
}

void Heavy_WSTD_DLAY::cReceive_RFLzIGPZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_PyrJGVG3_sendMessage);
}

void Heavy_WSTD_DLAY::cReceive_wNfMQqR3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_IEBAU5Pv_sendMessage);
}

void Heavy_WSTD_DLAY::cReceive_kPjdphhq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_m7O9Z5RQ, 0, m, &cVar_m7O9Z5RQ_sendMessage);
}

void Heavy_WSTD_DLAY::cReceive_iXW38ewf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Y18FzWi4_sendMessage(_c, 0, m);
  cMsg_e3RkmEph_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cReceive_MPgghF9k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_KJe8qW9r_sendMessage(_c, 0, m);
  cMsg_mAyZ6iV4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cReceive_SbNKxQIO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_q8PdgrG1_sendMessage);
}

void Heavy_WSTD_DLAY::cReceive_eDuAAHql_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_aTAPRaiQ, 0, m, &cVar_aTAPRaiQ_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_p3YgE2qW, 0, m, &cVar_p3YgE2qW_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_t2FtbrbM, 0, m, &cVar_t2FtbrbM_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_uXxq0oP9, 0, m, &cVar_uXxq0oP9_sendMessage);
  cMsg_4NHYinou_sendMessage(_c, 0, m);
  cMsg_anMmhJ1N_sendMessage(_c, 0, m);
  cMsg_Cr0DdcSR_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_PmWaAmKH, 0, m, &cVar_PmWaAmKH_sendMessage);
  cMsg_mF2PBnMU_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_che1FDdL, 0, m, &cVar_che1FDdL_sendMessage);
  cMsg_h4x4XJ8n_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_V636omAz, 0, m, &cVar_V636omAz_sendMessage);
  cMsg_ZyG7iRV7_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_3CC62zvN, 0, m, &cVar_3CC62zvN_sendMessage);
  cMsg_l8lzn7WC_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_AUPgHs5B, 0, m, &cVar_AUPgHs5B_sendMessage);
  cMsg_RLapHdOD_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_TAv3K7xJ, 0, m, &cVar_TAv3K7xJ_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_JjRR2dRc, 0, m, &cVar_JjRR2dRc_sendMessage);
  cMsg_6mRLnOcD_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_d3BDfN2g, 0, m, &cVar_d3BDfN2g_sendMessage);
  cMsg_jxkgFD2X_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cReceive_PrFZm3q9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_rpEPfjnH_sendMessage);
}

void Heavy_WSTD_DLAY::cReceive_PaNRhVGH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_SBW5yega, 0, m, &cVar_SBW5yega_sendMessage);
}

void Heavy_WSTD_DLAY::cReceive_NLbNglHM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_5WyPR3B8, 0, m, &cVar_5WyPR3B8_sendMessage);
}

void Heavy_WSTD_DLAY::cReceive_o3K1qW6Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_dCbNRisx_onMessage(_c, NULL, 0, m, NULL);
}




/*
 * Context Process Implementation
 */

int Heavy_WSTD_DLAY::process(float **inputBuffers, float **outputBuffers, int n) {
  while (hLp_hasData(&inQueue)) {
    hv_uint32_t numBytes = 0;
    ReceiverMessagePair *p = reinterpret_cast<ReceiverMessagePair *>(hLp_getReadBuffer(&inQueue, &numBytes));
    hv_assert(numBytes >= sizeof(ReceiverMessagePair));
    scheduleMessageForReceiver(p->receiverHash, &p->msg);
    hLp_consume(&inQueue);
  }

  sendBangToReceiver(0xDD21C0EB); // send to __hv_bang~ on next cycle
  const int n4 = n & ~HV_N_SIMD_MASK; // ensure that the block size is a multiple of HV_N_SIMD

  // temporary signal vars
  hv_bufferf_t Bf0, Bf1, Bf2, Bf3, Bf4, Bf5, Bf6;
  hv_bufferi_t Bi0, Bi1;

  // input and output vars
  hv_bufferf_t O0, O1;
  hv_bufferf_t I0, I1;

  // declare and init the zero buffer
  hv_bufferf_t ZERO; __hv_zero_f(VOf(ZERO));

  hv_uint32_t nextBlock = blockStartTimestamp;
  for (int n = 0; n < n4; n += HV_N_SIMD) {

    // process all of the messages for this block
    nextBlock += HV_N_SIMD;
    while (mq_hasMessageBefore(&mq, nextBlock)) {
      MessageNode *const node = mq_peek(&mq);
      node->sendMessage(this, node->let, node->m);
      mq_pop(&mq);
    }

    // load input buffers
    __hv_load_f(inputBuffers[0]+n, VOf(I0));
    __hv_load_f(inputBuffers[1]+n, VOf(I1));

    // zero output buffers
    __hv_zero_f(VOf(O0));
    __hv_zero_f(VOf(O1));

    // process all signal functions
    __hv_line_f(&sLine_emf4FDWb, VOf(Bf0));
    __hv_line_f(&sLine_oP4vcVFl, VOf(Bf1));
    __hv_tabhead_f(&sTabhead_oMjHonX9, VOf(Bf2));
    __hv_var_k_f_r(VOf(Bf3), -1.0f, -2.0f, -3.0f, -4.0f, -5.0f, -6.0f, -7.0f, -8.0f);
    __hv_add_f(VIf(Bf2), VIf(Bf3), VOf(Bf3));
    __hv_varread_f(&sVarf_vFWBgWZ0, VOf(Bf2));
    __hv_mul_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_varread_f(&sVarf_I3N2Uj0Z, VOf(Bf1));
    __hv_min_f(VIf(Bf2), VIf(Bf1), VOf(Bf1));
    __hv_zero_f(VOf(Bf2));
    __hv_max_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_sub_f(VIf(Bf3), VIf(Bf2), VOf(Bf2));
    __hv_floor_f(VIf(Bf2), VOf(Bf3));
    __hv_varread_f(&sVarf_k1z0rgMD, VOf(Bf1));
    __hv_zero_f(VOf(Bf4));
    __hv_lt_f(VIf(Bf3), VIf(Bf4), VOf(Bf4));
    __hv_and_f(VIf(Bf1), VIf(Bf4), VOf(Bf4));
    __hv_add_f(VIf(Bf3), VIf(Bf4), VOf(Bf4));
    __hv_cast_fi(VIf(Bf4), VOi(Bi0));
    __hv_var_k_i(VOi(Bi1), 1, 1, 1, 1, 1, 1, 1, 1);
    __hv_add_i(VIi(Bi0), VIi(Bi1), VOi(Bi1));
    __hv_tabread_if(&sTabread_kAxrWucA, VIi(Bi1), VOf(Bf4));
    __hv_tabread_if(&sTabread_N5g2ysVF, VIi(Bi0), VOf(Bf1));
    __hv_sub_f(VIf(Bf4), VIf(Bf1), VOf(Bf4));
    __hv_sub_f(VIf(Bf2), VIf(Bf3), VOf(Bf3));
    __hv_fma_f(VIf(Bf4), VIf(Bf3), VIf(Bf1), VOf(Bf1));
    __hv_var_k_f(VOf(Bf3), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_min_f(VIf(Bf1), VIf(Bf3), VOf(Bf3));
    __hv_var_k_f(VOf(Bf4), -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f);
    __hv_max_f(VIf(Bf3), VIf(Bf4), VOf(Bf4));
    __hv_line_f(&sLine_Lb0Wp4GL, VOf(Bf3));
    __hv_mul_f(VIf(Bf4), VIf(Bf3), VOf(Bf3));
    __hv_fma_f(VIf(I0), VIf(Bf0), VIf(Bf3), VOf(Bf3));
    __hv_line_f(&sLine_REWeOjqP, VOf(Bf0));
    __hv_line_f(&sLine_nS7XczOb, VOf(Bf4));
    __hv_tabhead_f(&sTabhead_b4PaNVby, VOf(Bf2));
    __hv_var_k_f_r(VOf(Bf5), -1.0f, -2.0f, -3.0f, -4.0f, -5.0f, -6.0f, -7.0f, -8.0f);
    __hv_add_f(VIf(Bf2), VIf(Bf5), VOf(Bf5));
    __hv_varread_f(&sVarf_cVsodALY, VOf(Bf2));
    __hv_mul_f(VIf(Bf4), VIf(Bf2), VOf(Bf2));
    __hv_varread_f(&sVarf_HS55iWfQ, VOf(Bf4));
    __hv_min_f(VIf(Bf2), VIf(Bf4), VOf(Bf4));
    __hv_zero_f(VOf(Bf2));
    __hv_max_f(VIf(Bf4), VIf(Bf2), VOf(Bf2));
    __hv_sub_f(VIf(Bf5), VIf(Bf2), VOf(Bf2));
    __hv_floor_f(VIf(Bf2), VOf(Bf5));
    __hv_varread_f(&sVarf_A3snDwVx, VOf(Bf4));
    __hv_zero_f(VOf(Bf6));
    __hv_lt_f(VIf(Bf5), VIf(Bf6), VOf(Bf6));
    __hv_and_f(VIf(Bf4), VIf(Bf6), VOf(Bf6));
    __hv_add_f(VIf(Bf5), VIf(Bf6), VOf(Bf6));
    __hv_cast_fi(VIf(Bf6), VOi(Bi0));
    __hv_var_k_i(VOi(Bi1), 1, 1, 1, 1, 1, 1, 1, 1);
    __hv_add_i(VIi(Bi0), VIi(Bi1), VOi(Bi1));
    __hv_tabread_if(&sTabread_m6Q314kp, VIi(Bi1), VOf(Bf6));
    __hv_tabread_if(&sTabread_WHlA7cSZ, VIi(Bi0), VOf(Bf4));
    __hv_sub_f(VIf(Bf6), VIf(Bf4), VOf(Bf6));
    __hv_sub_f(VIf(Bf2), VIf(Bf5), VOf(Bf5));
    __hv_fma_f(VIf(Bf6), VIf(Bf5), VIf(Bf4), VOf(Bf4));
    __hv_var_k_f(VOf(Bf5), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_min_f(VIf(Bf4), VIf(Bf5), VOf(Bf5));
    __hv_var_k_f(VOf(Bf6), -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f);
    __hv_max_f(VIf(Bf5), VIf(Bf6), VOf(Bf6));
    __hv_line_f(&sLine_CvraKWUP, VOf(Bf5));
    __hv_mul_f(VIf(Bf6), VIf(Bf5), VOf(Bf5));
    __hv_fma_f(VIf(I1), VIf(Bf0), VIf(Bf5), VOf(Bf5));
    __hv_varread_f(&sVarf_BSAMimAp, VOf(Bf0));
    __hv_add_f(VIf(I0), VIf(Bf0), VOf(Bf0));
    __hv_tabwrite_f(&sTabwrite_BLdRBwpo, VIf(Bf0));
    __hv_varread_f(&sVarf_v44uGGd9, VOf(Bf0));
    __hv_add_f(VIf(I1), VIf(Bf0), VOf(Bf0));
    __hv_tabwrite_f(&sTabwrite_4Uym1PVk, VIf(Bf0));
    __hv_varread_f(&sVarf_bhfHpHcJ, VOf(Bf0));
    __hv_mul_f(VIf(Bf1), VIf(Bf0), VOf(Bf0));
    __hv_varread_f(&sVarf_isN3OkZk, VOf(Bf1));
    __hv_rpole_f(&sRPole_eFbjgy40, VIf(Bf0), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_Y0YN5zNO, VOf(Bf0));
    __hv_mul_f(VIf(Bf1), VIf(Bf0), VOf(Bf0));
    __hv_varread_f(&sVarf_bwdL9FzE, VOf(Bf1));
    __hv_rpole_f(&sRPole_e7sE5NnO, VIf(Bf0), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_FkQJUbUs, VOf(Bf0));
    __hv_rpole_f(&sRPole_6IUyYLed, VIf(Bf1), VIf(Bf0), VOf(Bf0));
    __hv_var_k_f(VOf(Bf1), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_del1_f(&sDel1_DwTmzkuC, VIf(Bf0), VOf(Bf6));
    __hv_mul_f(VIf(Bf6), VIf(Bf1), VOf(Bf1));
    __hv_sub_f(VIf(Bf0), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_1bDGg8Zm, VOf(Bf0));
    __hv_mul_f(VIf(Bf1), VIf(Bf0), VOf(Bf0));
    __hv_line_f(&sLine_jLgUJtNn, VOf(Bf1));
    __hv_mul_f(VIf(Bf0), VIf(Bf1), VOf(Bf1));
    __hv_line_f(&sLine_IbXBpd4C, VOf(Bf0));
    __hv_varread_f(&sVarf_X3vIjACy, VOf(Bf6));
    __hv_mul_f(VIf(Bf4), VIf(Bf6), VOf(Bf6));
    __hv_varread_f(&sVarf_x0hlXezc, VOf(Bf4));
    __hv_rpole_f(&sRPole_14g6YBFI, VIf(Bf6), VIf(Bf4), VOf(Bf4));
    __hv_varread_f(&sVarf_A8aLz452, VOf(Bf6));
    __hv_mul_f(VIf(Bf4), VIf(Bf6), VOf(Bf6));
    __hv_varread_f(&sVarf_P1DTlET4, VOf(Bf4));
    __hv_rpole_f(&sRPole_zz8pgRKY, VIf(Bf6), VIf(Bf4), VOf(Bf4));
    __hv_varread_f(&sVarf_tEVKc4D4, VOf(Bf6));
    __hv_rpole_f(&sRPole_GbE9MX7F, VIf(Bf4), VIf(Bf6), VOf(Bf6));
    __hv_var_k_f(VOf(Bf4), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_del1_f(&sDel1_qdjCShOm, VIf(Bf6), VOf(Bf2));
    __hv_mul_f(VIf(Bf2), VIf(Bf4), VOf(Bf4));
    __hv_sub_f(VIf(Bf6), VIf(Bf4), VOf(Bf4));
    __hv_varread_f(&sVarf_4YuK04Zc, VOf(Bf6));
    __hv_mul_f(VIf(Bf4), VIf(Bf6), VOf(Bf6));
    __hv_line_f(&sLine_CIAsGIV6, VOf(Bf4));
    __hv_mul_f(VIf(Bf6), VIf(Bf4), VOf(Bf4));
    __hv_line_f(&sLine_yK7YDNCp, VOf(Bf6));
    __hv_mul_f(VIf(Bf4), VIf(Bf6), VOf(Bf6));
    __hv_fma_f(VIf(Bf1), VIf(Bf0), VIf(Bf6), VOf(Bf6));
    __hv_varwrite_f(&sVarf_BSAMimAp, VIf(Bf6));
    __hv_line_f(&sLine_UlLkROZF, VOf(Bf6));
    __hv_line_f(&sLine_CgrCZvKp, VOf(Bf0));
    __hv_mul_f(VIf(Bf1), VIf(Bf0), VOf(Bf0));
    __hv_fma_f(VIf(Bf4), VIf(Bf6), VIf(Bf0), VOf(Bf0));
    __hv_varwrite_f(&sVarf_v44uGGd9, VIf(Bf0));
    __hv_add_f(VIf(Bf3), VIf(O0), VOf(O0));
    __hv_add_f(VIf(Bf5), VIf(O1), VOf(O1));

    // save output vars to output buffer
    __hv_store_f(outputBuffers[0]+n, VIf(O0));
    __hv_store_f(outputBuffers[1]+n, VIf(O1));
  }

  blockStartTimestamp = nextBlock;

  return n4; // return the number of frames processed

}

int Heavy_WSTD_DLAY::processInline(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(!(n4 & HV_N_SIMD_MASK)); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s)
  float **const bIn = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bIn[0] = inputBuffers+(0*n4);
  bIn[1] = inputBuffers+(1*n4);

  // define the heavy output buffer for 2 channel(s)
  float **const bOut = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bOut[0] = outputBuffers+(0*n4);
  bOut[1] = outputBuffers+(1*n4);

  int n = process(bIn, bOut, n4);
  return n;
}

int Heavy_WSTD_DLAY::processInlineInterleaved(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(n4 & ~HV_N_SIMD_MASK); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s), uninterleave
  float *const bIn = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));
  #if HV_SIMD_SSE || HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 a = _mm_load_ps(inputBuffers+i);                // LRLR
    __m128 b = _mm_load_ps(inputBuffers+4+i);              // LRLR
    __m128 x = _mm_shuffle_ps(a, b, _MM_SHUFFLE(2,0,2,0)); // LLLL
    __m128 y = _mm_shuffle_ps(a, b, _MM_SHUFFLE(3,1,3,1)); // RRRR
    _mm_store_ps(bIn+j, x);
    _mm_store_ps(bIn+n4+j, y);
  }
  #elif HV_SIMD_NEON
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4x2_t a = vld2q_f32(inputBuffers+i); // load and uninterleave
    vst1q_f32(bIn+j, a.val[0]);
    vst1q_f32(bIn+n4+j, a.val[1]);
  }
  #else // HV_SIMD_NONE
  for (int j = 0; j < n4; ++j) {
    bIn[0*n4+j] = inputBuffers[0+2*j];
    bIn[1*n4+j] = inputBuffers[1+2*j];
  }
  #endif

  // define the heavy output buffer for 2 channel(s)
  float *const bOut = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));

  int n = processInline(bIn, bOut, n4);

  // interleave the heavy output into the output buffer
  #if HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 8, i += 16) {
    __m256 x = _mm256_load_ps(bOut+j);    // LLLLLLLL
    __m256 y = _mm256_load_ps(bOut+n4+j); // RRRRRRRR
    __m256 a = _mm256_unpacklo_ps(x, y);  // LRLRLRLR
    __m256 b = _mm256_unpackhi_ps(x, y);  // LRLRLRLR
    _mm256_store_ps(outputBuffers+i, a);
    _mm256_store_ps(outputBuffers+8+i, b);
  }
  #elif HV_SIMD_SSE
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 x = _mm_load_ps(bOut+j);    // LLLL
    __m128 y = _mm_load_ps(bOut+n4+j); // RRRR
    __m128 a = _mm_unpacklo_ps(x, y);  // LRLR
    __m128 b = _mm_unpackhi_ps(x, y);  // LRLR
    _mm_store_ps(outputBuffers+i, a);
    _mm_store_ps(outputBuffers+4+i, b);
  }
  #elif HV_SIMD_NEON
  // https://community.arm.com/groups/processors/blog/2012/03/13/coding-for-neon--part-5-rearranging-vectors
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4_t x = vld1q_f32(bOut+j);
    float32x4_t y = vld1q_f32(bOut+n4+j);
    float32x4x2_t z = {x, y};
    vst2q_f32(outputBuffers+i, z); // interleave and store
  }
  #else // HV_SIMD_NONE
  for (int i = 0; i < 2; ++i) {
    for (int j = 0; j < n4; ++j) {
      outputBuffers[i+2*j] = bOut[i*n4+j];
    }
  }
  #endif

  return n;
}
