/**
 * Copyright (c) 2025 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#ifndef _HEAVY_CONTEXT_WSTD_DLAY_HPP_
#define _HEAVY_CONTEXT_WSTD_DLAY_HPP_

// object includes
#include "HeavyContext.hpp"
#include "HvControlVar.h"
#include "HvControlSystem.h"
#include "HvSignalLine.h"
#include "HvSignalTabread.h"
#include "HvSignalVar.h"
#include "HvControlUnop.h"
#include "HvControlDelay.h"
#include "HvSignalDel1.h"
#include "HvMath.h"
#include "HvControlSlice.h"
#include "HvControlIf.h"
#include "HvTable.h"
#include "HvControlBinop.h"
#include "HvControlCast.h"
#include "HvSignalTabwrite.h"
#include "HvSignalRPole.h"

class Heavy_WSTD_DLAY : public HeavyContext {

 public:
  Heavy_WSTD_DLAY(double sampleRate, int poolKb=10, int inQueueKb=2, int outQueueKb=0);
  ~Heavy_WSTD_DLAY();

  const char *getName() override { return "WSTD_DLAY"; }
  int getNumInputChannels() override { return 2; }
  int getNumOutputChannels() override { return 2; }

  int process(float **inputBuffers, float **outputBuffer, int n) override;
  int processInline(float *inputBuffers, float *outputBuffer, int n) override;
  int processInlineInterleaved(float *inputBuffers, float *outputBuffer, int n) override;

  int getParameterInfo(int index, HvParameterInfo *info) override;
  struct Parameter {
    struct In {
      enum ParameterIn : hv_uint32_t {
        CROSS = 0xB6A8F09D, // Cross
        FEEDBACK = 0x57157946, // Feedback
        MIX = 0x97D46AC6, // Mix
        SYNC = 0x4A331B66, // Sync
        TIME = 0x58E5C2DB, // Time
        TIMESYNC = 0x49107604, // TimeSync
      };
    };
  };

 private:
  HvTable *getTableForHash(hv_uint32_t tableHash) override;
  void scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) override;

  // static sendMessage functions
  static void cVar_PZbaKyT3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_77Ap1qz6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_Tkysogw1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_o6y1pE10_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_knsfy0Yj_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_XgGGHenN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_aTAPRaiQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_nmgx4RnX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_E9Xv6yYY_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_yLqrvlyG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_p3YgE2qW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_0KiQRTqh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_Us54oHmx_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_8NJZY6x3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_t2FtbrbM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_ZUJt0Nqh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_q8PdgrG1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_EyGAf9ph_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_nEhIv7Yq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_bw7WZ9t0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_hIbKcKzv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_B10ywv37_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_JDtvsf2H_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_xfb0L59T_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_vXpprqpB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_XNPijd3Q_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_qiuQcfcP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_sKmTNGCB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_3dtAyK0K_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_rpEPfjnH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_sYBUimMt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_k9OX9xgY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_9lxQ1G8h_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_rBqUe9KB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_F1cdW4H7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_jjqDXsxK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_jQdimTgN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_O5YO2XS8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_HcLSaWyV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_LVrFPM68_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_BKgNX7ik_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_lOYvjmry_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_uXxq0oP9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_D0AG8uiz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_4NHYinou_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_6WxmILaG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_KwGxB0CF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_l6WSwE5H_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_zq9W55QJ_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_Ii2iJl7N_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_N0BaGJii_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_XhVxLnEJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_iO0I4ybK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_riauiRVY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_k9n2tsct_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_hMtYRHOI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_rKpaF13w_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_anMmhJ1N_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_ZMhZxrE7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_ZrZQiy8U_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_oHSyXk8S_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_cMwBNChz_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_XB3Rd6x1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_kOwQFr1w_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_JeDn2iCK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_6QkBu4Lq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_sPjSNYEe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_2ZH8Idlr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_h8HIXTgk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_bmXocgFj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_PmWaAmKH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Cr0DdcSR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_JR1Gjv8G_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_h0AkUZxY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_otQEu6up_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_TrDmpzHj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ug1hxhuE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_oXjfZdRu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_InX3GylI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_che1FDdL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_mF2PBnMU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_ecMcyAt4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_xYSDqeKM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_QDnXAqLv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_AGv9WNN3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_S7ZfCqVr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_vYEtxZpl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Sk7NIIug_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_y7kJh4Fn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_SIY38Oux_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_V636omAz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_h4x4XJ8n_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_8tpvHVNa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_fNLsFOnD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_X3stMeUt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_tlNzhii3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_dEXfpUCX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_MaffCoxn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_HYOeIJI9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_CetCT8fs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ltpjs0j2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_6mRLnOcD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_X3sq4UqO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_JjRR2dRc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_iL5vFiOv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_5scJTxJm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_1xSBHV9j_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_N1o7yguv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_jxkgFD2X_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_hC13uXjZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_d3BDfN2g_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_LTkeDZZ6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_XjthfrKP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_kjTt398t_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_IQLrfyxn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_3CC62zvN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ZyG7iRV7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_UFJGOZWE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_LqVZ77eD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_wYDVbz13_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_cn11LCGV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_KmlmVmlr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ickWJYNK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_D5azkSxi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_AUPgHs5B_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_l8lzn7WC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_PGO5IagE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_gCIIVgH9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ofSX4ZnR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_GCbrokq1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_yMuJakTq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_8hQmbsKF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_i80uts2E_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_b5RSyRue_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_znwrxYen_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_TAv3K7xJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_RLapHdOD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_qsWSv9aG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_EDpc2UBj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_HB0jwDjH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_oxb2KLbX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_TJ3eMJPR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_JBInPdqY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_0ejbn1c3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_XAHIfK9u_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_1bkFcSEw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_z9B3HWHc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_HGnDe7D6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_DRCbeWQQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_msbWbXgN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_sLov1csS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_GNc5ZNyv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_yRHi62tf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_yhesJSHq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Y18FzWi4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_e3RkmEph_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_KJe8qW9r_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_mAyZ6iV4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_SBW5yega_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_rbRr6Wfn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_3YVtq791_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_Rb0MhOSZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_m7O9Z5RQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_Z7a7jXva_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_3BKWgmrH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_LBPr5BVp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_psV60ts8_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_ExvpjG6Y_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSlice_vtFmCa2e_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_pTYm3pBS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_y91VAArF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_9UCNgR4x_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_gzwsb9SD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_uwQzxRP4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_eERrjgFM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_hTdLFlxa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_5WyPR3B8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_dCbNRisx_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cCast_CpknqNbu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_h8x9A1Yr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_WPR7XzHu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_vU6Yg17T_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_cPDXiepd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_RKQDuRYi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_acafYlU1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_NqxHmtcr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_KUDxWa9a_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_CDr5324S_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_qLgcwuqC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_564sE2xu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_t7rdEsyw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_3f6h1dz7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_SbPYvnba_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_WnVEyx24_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_fmkoVULX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ROys5eUj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_OqrGb7tJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_XZLNAYhA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Gatr9wno_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_JDLiXeoU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_LiWZrm3z_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_HMe8ASua_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_fZ8BO2gc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_XyVVlXPw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_p93RNYfy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_x434Mj6C_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_FmTP4aUT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_7eyKfRXn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ISFHjhSJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_iPgIR0ab_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_vUZswUXr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_q2SDC9dR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_qJbpXKnI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_PyrJGVG3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_IEBAU5Pv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_72iZ9rYJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_PbxkHKr8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_RHHi3KiD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_8whLb0ZO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_HjyGqrxD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_hwQZnh9z_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_edHCusAk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_bbQ0nm85_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_FBPUN72b_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_exbuk3Ra_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_RFLzIGPZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_wNfMQqR3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_kPjdphhq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_iXW38ewf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_MPgghF9k_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_SbNKxQIO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_eDuAAHql_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_PrFZm3q9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_PaNRhVGH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_NLbNglHM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_o3K1qW6Q_sendMessage(HeavyContextInterface *, int, const HvMessage *);

  // objects
  SignalLine sLine_emf4FDWb;
  SignalLine sLine_oP4vcVFl;
  SignalTabhead sTabhead_oMjHonX9;
  SignalTabread sTabread_kAxrWucA;
  SignalTabread sTabread_N5g2ysVF;
  SignalLine sLine_Lb0Wp4GL;
  SignalLine sLine_REWeOjqP;
  SignalLine sLine_nS7XczOb;
  SignalTabhead sTabhead_b4PaNVby;
  SignalTabread sTabread_m6Q314kp;
  SignalTabread sTabread_WHlA7cSZ;
  SignalLine sLine_CvraKWUP;
  SignalTabwrite sTabwrite_BLdRBwpo;
  SignalTabwrite sTabwrite_4Uym1PVk;
  SignalRPole sRPole_eFbjgy40;
  SignalRPole sRPole_e7sE5NnO;
  SignalRPole sRPole_6IUyYLed;
  SignalDel1 sDel1_DwTmzkuC;
  SignalLine sLine_jLgUJtNn;
  SignalLine sLine_IbXBpd4C;
  SignalRPole sRPole_14g6YBFI;
  SignalRPole sRPole_zz8pgRKY;
  SignalRPole sRPole_GbE9MX7F;
  SignalDel1 sDel1_qdjCShOm;
  SignalLine sLine_CIAsGIV6;
  SignalLine sLine_yK7YDNCp;
  SignalLine sLine_UlLkROZF;
  SignalLine sLine_CgrCZvKp;
  ControlVar cVar_PZbaKyT3;
  ControlVar cVar_77Ap1qz6;
  ControlVar cVar_Tkysogw1;
  ControlVar cVar_o6y1pE10;
  ControlSlice cSlice_XgGGHenN;
  ControlVar cVar_aTAPRaiQ;
  ControlSlice cSlice_yLqrvlyG;
  ControlVar cVar_p3YgE2qW;
  ControlSlice cSlice_8NJZY6x3;
  ControlVar cVar_t2FtbrbM;
  ControlBinop cBinop_q8PdgrG1;
  ControlBinop cBinop_EyGAf9ph;
  ControlBinop cBinop_hIbKcKzv;
  ControlBinop cBinop_B10ywv37;
  ControlBinop cBinop_vXpprqpB;
  ControlBinop cBinop_qiuQcfcP;
  ControlBinop cBinop_sKmTNGCB;
  ControlBinop cBinop_3dtAyK0K;
  ControlBinop cBinop_rpEPfjnH;
  ControlBinop cBinop_sYBUimMt;
  ControlBinop cBinop_k9OX9xgY;
  ControlBinop cBinop_9lxQ1G8h;
  ControlBinop cBinop_jjqDXsxK;
  ControlBinop cBinop_O5YO2XS8;
  ControlBinop cBinop_HcLSaWyV;
  ControlBinop cBinop_LVrFPM68;
  ControlSlice cSlice_lOYvjmry;
  ControlVar cVar_uXxq0oP9;
  ControlDelay cDelay_KwGxB0CF;
  ControlDelay cDelay_l6WSwE5H;
  ControlBinop cBinop_Ii2iJl7N;
  HvTable hTable_N0BaGJii;
  ControlBinop cBinop_iO0I4ybK;
  ControlDelay cDelay_ZrZQiy8U;
  ControlDelay cDelay_oHSyXk8S;
  ControlBinop cBinop_XB3Rd6x1;
  HvTable hTable_kOwQFr1w;
  ControlBinop cBinop_6QkBu4Lq;
  ControlVar cVar_PmWaAmKH;
  ControlBinop cBinop_h0AkUZxY;
  ControlBinop cBinop_otQEu6up;
  SignalVarf sVarf_isN3OkZk;
  ControlBinop cBinop_ug1hxhuE;
  ControlBinop cBinop_oXjfZdRu;
  ControlBinop cBinop_InX3GylI;
  SignalVarf sVarf_bhfHpHcJ;
  ControlVar cVar_che1FDdL;
  ControlBinop cBinop_xYSDqeKM;
  ControlBinop cBinop_QDnXAqLv;
  SignalVarf sVarf_bwdL9FzE;
  ControlBinop cBinop_S7ZfCqVr;
  ControlBinop cBinop_vYEtxZpl;
  ControlBinop cBinop_Sk7NIIug;
  SignalVarf sVarf_Y0YN5zNO;
  ControlBinop cBinop_y7kJh4Fn;
  ControlBinop cBinop_SIY38Oux;
  SignalVarf sVarf_FkQJUbUs;
  ControlVar cVar_V636omAz;
  ControlBinop cBinop_fNLsFOnD;
  ControlBinop cBinop_X3stMeUt;
  ControlBinop cBinop_dEXfpUCX;
  ControlBinop cBinop_MaffCoxn;
  ControlBinop cBinop_HYOeIJI9;
  ControlBinop cBinop_CetCT8fs;
  ControlBinop cBinop_ltpjs0j2;
  SignalVarf sVarf_1bDGg8Zm;
  ControlVar cVar_JjRR2dRc;
  ControlBinop cBinop_5scJTxJm;
  ControlBinop cBinop_N1o7yguv;
  SignalVarf sVarf_k1z0rgMD;
  SignalVarf sVarf_vFWBgWZ0;
  SignalVarf sVarf_I3N2Uj0Z;
  ControlVar cVar_d3BDfN2g;
  ControlBinop cBinop_XjthfrKP;
  ControlBinop cBinop_IQLrfyxn;
  SignalVarf sVarf_A3snDwVx;
  SignalVarf sVarf_cVsodALY;
  SignalVarf sVarf_HS55iWfQ;
  ControlVar cVar_3CC62zvN;
  ControlBinop cBinop_LqVZ77eD;
  ControlBinop cBinop_wYDVbz13;
  SignalVarf sVarf_x0hlXezc;
  ControlBinop cBinop_KmlmVmlr;
  ControlBinop cBinop_ickWJYNK;
  ControlBinop cBinop_D5azkSxi;
  SignalVarf sVarf_X3vIjACy;
  ControlVar cVar_AUPgHs5B;
  ControlBinop cBinop_gCIIVgH9;
  ControlBinop cBinop_ofSX4ZnR;
  SignalVarf sVarf_P1DTlET4;
  ControlBinop cBinop_yMuJakTq;
  ControlBinop cBinop_8hQmbsKF;
  ControlBinop cBinop_i80uts2E;
  SignalVarf sVarf_A8aLz452;
  ControlBinop cBinop_b5RSyRue;
  ControlBinop cBinop_znwrxYen;
  SignalVarf sVarf_tEVKc4D4;
  ControlVar cVar_TAv3K7xJ;
  ControlBinop cBinop_EDpc2UBj;
  ControlBinop cBinop_HB0jwDjH;
  ControlBinop cBinop_TJ3eMJPR;
  ControlBinop cBinop_JBInPdqY;
  ControlBinop cBinop_0ejbn1c3;
  ControlBinop cBinop_XAHIfK9u;
  ControlBinop cBinop_1bkFcSEw;
  SignalVarf sVarf_4YuK04Zc;
  SignalVarf sVarf_BSAMimAp;
  SignalVarf sVarf_v44uGGd9;
  ControlVar cVar_SBW5yega;
  ControlBinop cBinop_rbRr6Wfn;
  ControlIf cIf_3YVtq791;
  ControlIf cIf_Rb0MhOSZ;
  ControlVar cVar_m7O9Z5RQ;
  ControlVar cVar_Z7a7jXva;
  ControlVar cVar_3BKWgmrH;
  ControlVar cVar_LBPr5BVp;
  ControlSlice cSlice_ExvpjG6Y;
  ControlSlice cSlice_vtFmCa2e;
  ControlVar cVar_pTYm3pBS;
  ControlIf cIf_y91VAArF;
  ControlBinop cBinop_uwQzxRP4;
  ControlVar cVar_5WyPR3B8;
  ControlBinop cBinop_3f6h1dz7;
  ControlBinop cBinop_SbPYvnba;
  ControlBinop cBinop_qJbpXKnI;
  ControlBinop cBinop_PyrJGVG3;
  ControlBinop cBinop_IEBAU5Pv;
  ControlBinop cBinop_RHHi3KiD;
  ControlBinop cBinop_8whLb0ZO;
  ControlBinop cBinop_HjyGqrxD;
};

#endif // _HEAVY_CONTEXT_WSTD_DLAY_HPP_
